pyUSID
======

.. image:: https://travis-ci.com/pycroscopy/pyUSID.svg?branch=master
    :target: https://travis-ci.com/pycroscopy/pyUSID
    :alt: TravisCI

.. image:: https://img.shields.io/pypi/v/pyUSID.svg
    :target: https://pypi.org/project/pyUSID/
    :alt: PyPI

.. image:: https://coveralls.io/repos/github/pycroscopy/pyUSID/badge.svg?branch=master
    :target: https://coveralls.io/github/pycroscopy/pyUSID?branch=master
    :alt: coverage
    
.. image:: https://img.shields.io/pypi/l/pyUSID.svg
    :target: https://pypi.org/project/pyUSID/
    :alt: License
    
.. image:: http://pepy.tech/badge/pyUSID
    :target: http://pepy.tech/project/pyUSID
    :alt: Downloads

.. image:: https://zenodo.org/badge/138171750.svg
   :target: https://zenodo.org/badge/latestdoi/138171750
   :alt: DOI
    
Framework for storing, visualizing, and processing Universal Spectroscopic and Imaging Data (USID)

Please see our `website <https://pycroscopy.github.io/pyUSID/about.html>`_ for more information.
